==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Layer/ts/Layer_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Herramientas de capa</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Mostrar herramientas de capa</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Capa</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Showing all layers</source>
        <translation>Mostrar todas las capas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Ocultar todas las capas</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Locking all layers</source>
        <translation>Bloquear todas las capas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Desbloquear todas las capas</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--
Capacidad de remuestreo de datos de capa de mapa rster de GRASS.
Capacidad de remuestreo de datos de capa de mapa rster de GRASS</translatorcomment>
        <translation>Datos de la capa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Nombre de capa:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Trazador</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Grosor de línea:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--ignored colon--
--file: LinetypeSettings_es.ts--</translatorcomment>
        <translation>Tipo de línea:</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espacios iniciales o finales.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nombre de la capa está vacía.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Capa ya existe.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Layer/ts/Layer_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+97"/>
        <source>Layer Tools</source>
        <translation>Herramientas de capa</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Mostrar herramientas de capa</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Capa</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Showing all layers</source>
        <translation>Mostrar todas las capas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Ocultar todas las capas</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Thawing all layers</source>
        <translation>Descongelación todas las capas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Freezing all layers</source>
        <translation>Congelar todas las capas</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Locking all layers</source>
        <translation>Bloquear todas las capas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Desbloquear todas las capas</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--
Capacidad de remuestreo de datos de capa de mapa rster de GRASS.
Capacidad de remuestreo de datos de capa de mapa rster de GRASS</translatorcomment>
        <translation>Datos de la capa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Nombre de capa:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Trazador</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Grosor de línea:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--ignored colon--
--file: LinetypeSettings_es.ts--</translatorcomment>
        <translation>Tipo de línea:</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+191"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espacios iniciales o finales.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nombre de la capa está vacía.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Capa ya existe.</translation>
    </message>
</context>
</TS>
